#!/bin/sh -e

case "$1" in
at4x0a)
	echo "$0: not yet supported \"$1\"."
	exit 1
	PLATFORM="at4x0a"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm926ej-s"
	;;
""|s3c24xx)
	PLATFORM="s3c24xx"
	CROSS_BUILD="i686-linux"
	CROSS_TARGET="arm-linux"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920"
	;;
s3c64xx)
	PLATFORM="s3c64xx"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-none-linux-gnueabi"
  CROSS_OPT="-O2 -mcpu=arm1176jzf-s -mfpu=vfp -mfp=vfp -march=armv6k -mtune=arm1176jzf-s -mfloat-abi=softfp"
	CROSS_CPU="arm1176jzf-s"
	;;
omap2)
	echo "$0: not yet supported \"$1\"."
	exit 1
	PLATFORM="omap2"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
titan2)
	PLATFORM="titan2"
	CROSS_BUILD="i686-pc-linux-gnu"
	#CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	# Build for now with temp toolchain 
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	exit 1
	;;
esac

PROGNAME="glib"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}"
INSDIR="${PWD}/ins-${PLATFORM}"

export BUILD_CC="gcc"
export CC="${CROSS_TARGET}-gcc"
export CFLAGS="${CROSS_OPT} -mcpu=${CROSS_CPU} -ffunction-sections -fdata-sections"
export CXX=arm-linux-gcc
export CXX="${CROSS_TARGET}-gcc"
export CXX="${CROSS_TARGET}-g++"
export CXXFLAGS="${CFLAGS}"
export F77="${CROSS_TARGET}-g77"
export AS="${CROSS_TARGET}-as"
export LD="${CROSS_TARGET}-ld"
export LDFLAGS="-Wl,--gc-sections"
export AR="${CROSS_TARGET}-ar"
export NM="${CROSS_TARGET}-nm"
export RANLIB="${CROSS_TARGET}-ranlib"
export STRIP="${CROSS_TARGET}-strip"

if test -e "aclocal.m4"; then
rm -f aclocal.m4
fi
aclocal
#automake
if test -e "config.cache"; then
rm -f config.cache
fi
echo "glib_cv_stack_grows=${glib_cv_stack_grows=no}" >config.cache
echo "glib_cv_uscore=${glib_cv_uscore=no}" >>config.cache
echo "ac_cv_func_posix_getpwuid_r=${ac_cv_func_posix_getpwuid_r=no}" >>config.cache
if test -e "configure"; then
rm -f configure
fi
autoconf

if test -e "glib/galias.h"; then
mv -f glib/galias.h glib/galias.h_bk
fi
if test -e "glib/galiasdef.c"; then
mv -f glib/galiasdef.c glib/galiasdef.c_bk
fi

mkdir -p "${OBJDIR}"
cd "${OBJDIR}"

echo "**** Configuring ${PROGNAME} for ${PLATFORM}..."
"${SRCDIR}/configure" --prefix="/" \
	  --build="${CROSS_BUILD}" \
	  --host="${CROSS_TARGET}" \
	  --target="${CROSS_TARGET}" \
          --disable-shared \
	  --enable-debug=no \
	  --enable-iconv-cache=no \
	  --with-libiconv=no \
	  --disable-nls \
	  --enable-gc-friendly \
	  --disable-mem-pools \
	  --cache-file=${SRCDIR}/config.cache \
	  --with-threads=posix 

make clean 
	  
echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make &&
echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install
  
